#
# spec file for package ragel
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ragel
Version:        7.0.4
Release:        1.15
Summary:        Finite state machine compiler
License:        MIT
Group:          Development/Tools/Other
URL:            https://www.colm.net/open-source/ragel/

#Git-Clone:	https://github.com/adrian-thurston/ragel
Source:         https://www.colm.net/files/ragel/%name-%version.tar.gz
Source2:        %name.keyring
Patch1:         paths.patch
BuildRequires:  automake
BuildRequires:  colm-devel = 0.14.7
BuildRequires:  gcc-c++
BuildRequires:  kelbt
BuildRequires:  libtool
Obsoletes:      libragel0 < %version-%release

%description
Ragel compiles finite state machines from regular languages into
executable C, C++, Objective-C, or D code. Ragel state machines can
not only recognize byte sequences as regular expression machines do,
but can also execute code at arbitrary points in the recognition of a
regular language. Code embedding is done using inline operators that
do not disrupt the regular language syntax.

%prep
%autosetup -p1

%build
autoreconf -fiv
export CXXFLAGS="%optflags -Wno-narrowing"
%configure --docdir="%_docdir/%name" --includedir="%_includedir/ragel" \
	--datadir="%_datadir" --disable-static --disable-manual
%make_build

%check
make check

%install
%make_install
b="%buildroot"
c="$b/%_datadir/vim/site/syntax"
mkdir -p "$c"
install -pm0644 ragel*.vim "$c/"
rm -Rf "$b/%_libdir"/*.la
# no headers available
rm -f "$b/%_libdir/libragel.so"

mkdir -p "$b/%_datadir/colm"
mv "$b/%_datadir"/*.lm "$b/%_datadir/colm/"

%files
%license COPYING
%doc %_docdir/%name
%_bindir/ragel*
%_mandir/man1/ragel.1*
%_datadir/vim/
%_datadir/colm/
%_libdir/libragel.so.0*

%changelog
* Mon Apr 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.0.4
  * No changelog provided
  * The ragel-devel package is gone. A number of header files seem
    to have moved to colm-devel (but in new locations, so may
    need update "#include" lines in your programs).
- Add paths.patch
* Wed Aug 26 2020 Jan Engelhardt <jengelh@inai.de>
- Update Git URL.
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 7.0.0.12
  * No changelog provided
* Fri Oct 26 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 7.0.0.11
  * No changelog was provided again
* Fri Jun  9 2017 jengelh@inai.de
- Update to new upstream release 7.0.0.10
  * No changelog was provided
* Sat Mar 11 2017 sfalken@opensuse.org
- Edited %%files to explicitly package %%{_docdir}/%%{name} to clear
  unpackaged files builderror in openSUSE:Factory
* Tue Nov 29 2016 jengelh@inai.de
- Update to new upstream 7.0.0.9
  * No changelog was provided
- Drop typesizes.diff (applied upstream)
* Thu Jun 23 2016 jengelh@inai.de
- Update to new release 7.0.0.6
  * A condition implementation overhaul. Rather than augment the
  input char with the result of condition evaluation, the input
  char transition is found, then the condition is evaluated and
  the transition further refined. This is conditions done right.
  * An intermediate codegen language. It is now possible to add
  languages without understanding ragel internals. All that is
  needed is a translation from a simple intermediate psudo-code.
  * NFA features for those hard-to-parse constructs and giant unions.
- Add typesizes.diff
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 6.9
  * updated command-line synopsis
  * ocaml: fix missing semicolon
  * ocaml: support -G1
  * ocaml: choose a unique name for type state
  * ruby: reduce the amount of calls to GET_WIDE_KEY()
  * union test case: warning fix
  * omit line directives around expression-oriented write statements
  * use AS_IF and test command to check if the DIST file is present
  * added missing std:: using
  * go: added '//line' directive support
- Add gpg signature and project keyring fof gpg verification
- Remove 0001-explicit-methods-inherited-from-base-templates.patch;
  merged on upstream release
* Fri Nov 16 2012 jengelh@inai.de
- Initial package (version 6.7) for build.opensuse.org
